import { NonNullablePaths } from '@wix/sdk-types';

interface Conversation {
    /**
     * Conversation ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /**
     * ID of the visitor, contact, or member who is chatting with the business.
     * @readonly
     */
    participant?: IdentificationData;
    /**
     * List of communication channels where the visitor, contact, or member can receive messages.
     * @readonly
     */
    channels?: ChannelTypeWithLiterals[];
    /** Display name and avatar for the business. */
    businessDisplayData?: ConversationDisplayData;
    /** Display name and avatar for the visitor, contact, or member. */
    participantDisplayData?: ConversationDisplayData;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of an anonymous site visitor.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * Member ID. See the Members API for more information.
     * @format GUID
     */
    memberId?: string;
    /**
     * Contact ID. See the Contacts API for more information.
     * @format GUID
     * @readonly
     */
    contactId?: string | null;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of an anonymous site visitor.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * Member ID. See the Members API for more information.
     * @format GUID
     */
    memberId?: string;
}
declare enum ChannelType {
    UNKNOWN_CHANNEL_TYPE = "UNKNOWN_CHANNEL_TYPE",
    CHAT = "CHAT",
    EMAIL = "EMAIL",
    SMS = "SMS",
    FACEBOOK = "FACEBOOK",
    INSTAGRAM = "INSTAGRAM",
    WHATSAPP = "WHATSAPP"
}
/** @enumType */
type ChannelTypeWithLiterals = ChannelType | 'UNKNOWN_CHANNEL_TYPE' | 'CHAT' | 'EMAIL' | 'SMS' | 'FACEBOOK' | 'INSTAGRAM' | 'WHATSAPP';
interface ConversationDisplayData {
    /**
     * Display name.
     * @readonly
     */
    name?: string;
    /**
     * Avatar image URL.
     * @readonly
     * @format WEB_URL
     */
    imageUrl?: string | null;
}
interface ConversationsMerged {
    /** List of old conversation IDs. */
    oldConversationIds?: string[];
    /**
     * New conversation ID.
     * @format GUID
     */
    targetConversationId?: string;
}
interface GetConversationRequest {
    /**
     * Conversation ID.
     * @format GUID
     */
    conversationId: string;
}
interface GetConversationResponse {
    /** Retrieved conversation. */
    conversation?: Conversation;
}
interface GetOrCreateConversationRequest {
    /**
     * ID of the visitor, contact, or member chatting with the business.
     *
     * Required for 3rd-party apps.
     */
    participantId?: ParticipantId;
}
interface ParticipantId extends ParticipantIdIdOneOf {
    /**
     * Contact ID. See the Contacts API for more information.
     * @format GUID
     */
    contactId?: string;
    /**
     * ID of an anonymous site visitor.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * Member ID. See the Members API for more information.
     * @format GUID
     */
    memberId?: string;
}
/** @oneof */
interface ParticipantIdIdOneOf {
    /**
     * Contact ID. See the Contacts API for more information.
     * @format GUID
     */
    contactId?: string;
    /**
     * ID of an anonymous site visitor.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * Member ID. See the Members API for more information.
     * @format GUID
     */
    memberId?: string;
}
interface GetOrCreateConversationResponse {
    /** Created or retrieved conversation. */
    conversation?: Conversation;
    /**
     * Indicates whether the conversation previously exists or was just created.
     *
     * If `true`, the conversation was just created.
     * If `false`, the conversation already existed.
     */
    newConversation?: boolean;
}
interface ListConversationsRequest {
    paging?: CursorPaging;
    /** only message time is supported for field name */
    sorting?: Sorting;
}
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface ListConversationsResponse {
    conversations?: Conversation[];
    pagingMetadata?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface DeleteConversationRequest {
    /** @format GUID */
    conversationId?: string;
}
interface DeleteConversationResponse {
}
interface AddConversationChannelsRequest {
    /** @format GUID */
    conversationId?: string;
    conversationChannels?: ConversationChannel[];
}
interface ConversationChannel {
    channel?: ChannelTypeWithLiterals;
    /** TODO rename? - Shalom */
    recipients?: string[];
}
interface AddConversationChannelsResponse {
}
interface ChatroomsMerged {
    /** old chatroom ids */
    oldChatroomIds?: string[];
    /**
     * new chatroom id
     * @format GUID
     */
    targetChatroomId?: string;
}
interface Empty {
}
interface ReadConversationRequest {
    /** @format GUID */
    conversationId?: string;
    /** @maxLength 100 */
    channelId?: string | null;
    readBy?: ParticipantId;
    timestamp?: Date | null;
}
interface ReadConversationResponse {
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: WebhooksIdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface WebhooksIdentificationData extends WebhooksIdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface WebhooksIdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
type GetConversationApplicationErrors = {
    code?: 'NOT_OWNED_BY_BUSINESS';
    description?: string;
    data?: Record<string, any>;
} | {
    code?: 'CONVERSATION_NOT_FOUND';
    description?: string;
    data?: Record<string, any>;
};
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: WebhooksIdentificationData;
}
interface EventMetadata extends BaseEventMetadata {
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
interface ConversationConversationsMergedEnvelope {
    data: ConversationsMerged;
    metadata: EventMetadata;
}
/**
 * Triggered when the conversation
 * is merged, for example when contacts are merged
 * or when a visitor becomes a contact.
 *
 * If messages exist in both conversations when they merge,
 * the messages are preserved in chronological order.
 * @permissionScope Manage Inbox Messages
 * @permissionScopeId SCOPE.DC-INBOX.MANAGE-MSGS
 * @permissionScope Read Inbox Messages
 * @permissionScopeId SCOPE.DC-INBOX.READ-MSGS
 * @permissionId INBOX.READ_CONVERSATIONS
 * @webhook
 * @eventType wix.crm.inbox.v2.conversation_conversations_merged
 * @serviceIdentifier com.wixpress.inbox.v2.ConversationsService
 * @slug conversations_merged
 */
declare function onConversationConversationsMerged(handler: (event: ConversationConversationsMergedEnvelope) => void | Promise<void>): void;
type ConversationNonNullablePaths = `_id` | `participant.anonymousVisitorId` | `participant.memberId` | `channels` | `businessDisplayData.name` | `participantDisplayData.name`;
/**
 * Retrieves a conversation by conversation ID.
 *
 * If you don't have the conversation ID, use Get Or Create Conversation in the Conversations API
 * to retrieve the conversation with the visitor, contact, or member ID.
 * @param conversationId - Conversation ID.
 * @public
 * @requiredField conversationId
 * @permissionId INBOX.READ_CONVERSATIONS
 * @applicableIdentity APP
 * @returns Retrieved conversation.
 * @fqn com.wixpress.inbox.v2.ConversationsService.GetConversation
 */
declare function getConversation(conversationId: string): Promise<NonNullablePaths<Conversation, ConversationNonNullablePaths> & {
    __applicationErrorsType?: GetConversationApplicationErrors;
}>;
/**
 * Retrieves a conversation by the specified visitor, contact, or member ID. If the conversation doesn't exist for the specified visitor, contact, or member, the method creates a new conversation.
 * @param participantId - ID of the visitor, contact, or member chatting with the business.
 *
 * Required for 3rd-party apps.
 * @public
 * @requiredField participantId
 * @param undefined - null
 * @permissionId INBOX.CREATE_CONVERSATIONS
 * @applicableIdentity APP
 * @fqn com.wixpress.inbox.v2.ConversationsService.GetOrCreateConversation
 */
declare function getOrCreateConversation(participantId: ParticipantId): Promise<NonNullablePaths<GetOrCreateConversationResponse, {
    [P in ConversationNonNullablePaths]: `conversation.${P}`;
}[ConversationNonNullablePaths] | `newConversation`>>;

export { type ActionEvent, type AddConversationChannelsRequest, type AddConversationChannelsResponse, type BaseEventMetadata, ChannelType, type ChannelTypeWithLiterals, type ChatroomsMerged, type Conversation, type ConversationChannel, type ConversationConversationsMergedEnvelope, type ConversationDisplayData, type ConversationsMerged, type CursorPaging, type Cursors, type DeleteConversationRequest, type DeleteConversationResponse, type DomainEvent, type DomainEventBodyOneOf, type Empty, type EntityCreatedEvent, type EntityDeletedEvent, type EntityUpdatedEvent, type EventMetadata, type GetConversationApplicationErrors, type GetConversationRequest, type GetConversationResponse, type GetOrCreateConversationRequest, type GetOrCreateConversationResponse, type IdentificationData, type IdentificationDataIdOneOf, type ListConversationsRequest, type ListConversationsResponse, type MessageEnvelope, type PagingMetadataV2, type ParticipantId, type ParticipantIdIdOneOf, type ReadConversationRequest, type ReadConversationResponse, type RestoreInfo, SortOrder, type SortOrderWithLiterals, type Sorting, WebhookIdentityType, type WebhookIdentityTypeWithLiterals, type WebhooksIdentificationData, type WebhooksIdentificationDataIdOneOf, getConversation, getOrCreateConversation, onConversationConversationsMerged };
